package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````R!<!`#0```!P`0$```0`!30`(``)
M`"@`'``;``$``'`XA@``.(8!`#B&`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!$A@``1(8```4```````$`
M`0```-S]``#<_0(`W/T"`#P"``!@`@``!@```````0`"````Z/T``.C]`@#H
M_0(`"`$```@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DW/T`
M`-S]`@#<_0(`)`(``"0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`R^H+$=N-KL27-\WK\K*X=.\R<I4$
M````$`````$```!'3E4```````,````"`````````$,````%````$`````D`
M``#@&+0B@>4'D@@*RF`&=4`Y@@`"1PHA`9&DP!0`!+K`D`.`@@@5T$"D3B""
M(92$T*!(`0$TX60&"!P7!)TJD4NH``````4````'``````````D````*````
M#0````\````0````$0```!,````7````&0``````````````&P`````````>
M````'P`````````A````(@```"4`````````*0```"H`````````*P```"P`
M```N````,```````````````,0`````````R````-0```#8````X````.P``
M`#T````^````0````$$```!$````1@```$@```!*````3@```$\```!0````
M40```%(```!3````5````%8```!7`````````%H```!<````7@``````````
M`````````&$```!C`````````*("]AD+BA!7R-6R<:/@^TDKT.$BSDJN_Z):
M[Y"?(L>H?.T1#_NA;&`Y\HL<S3\,KV[%WQ]]D!#IK$OCP#RM.0WH^\/"[3^0
M`G9OXW`'I(?_K'`.KP$C^:1J&IY0%NI:\2]./?9[\$IK0F9+$(%T@@U_J9R;
MZH2*')!U@@TA8F0'AO"6?%COEWG.WD<M7Y:3'!N?UKT5C"7,,V+;[;(!BV_M
M+/:+XD?&`;_:5QO%N9Q`P^4_+$!-G7Q"^M>'IYN3'`4RI850[A'C[=Z3'"[%
MF[:8(M1H][[\D:;=HVN)!W#3=U0\E"P.L7.90NZA#3J7"X;YG(&<NY,<QP[@
M/6"8[Q+;]P!>+-_^2#]^EGQBT/J":PE#UB1U@@T^GD)$5I):4F]Z:?KO"U'Y
M:W^:?$-%U>PA_^0.63M`']^%($_2402$U634?,DY0!_@IP(*]B/.(+OCDGR\
MT$M]5]N3'#"X@@U1&WU?NI63'`"O-.C#CH?__-+O#V>OS&;9<5@<````````
M``````````````$``````````````"`````0```````````````@````+```
M````````````(````&,``````````````!8````R`0`````````````2````
MQ@```"@``P`!````$0`8`!$!```<$P$``````!(```!F!```M"0!`'@$```2
M``T`NP$`````````````$@```*D#`````````````!(```"S`0``````````
M```2````,0(`````````````$@```+\"`````````````!(````]!```M"D!
M``P!```2``T`9P(``"```P`$````$0`8`,4"`````````````!(```"R`P``
M&#,!`/P````2``T`5```````````````$@```+X#``"$0P$`!````!$`#P"+
M`0`````````````2````H@``````````````$@```$L!`````````````!(`
M``"*`@`````````````2````D@(`````````````$@```-P!````````````
M`!(```"N`@`````````````2````C0,``!1"`0!$`0``$@`-`)D"````````
M`````!(```!5`@`````````````2````9`$``-`3`0``````$@````$"````
M`````````!(```!N`@`````````````2````EP,``)PI`0`8````$@`-`$X"
M`````````````!(```"@`@`````````````2````Z0(``.3]`@`$````$0`4
M```!`````````````!(```#[`P``/``#```````0`!@`*00``,`J`0#8!0``
M$@`-`*<"`````````````!(```#K`0`````````````2````&P0``%Q``0!\
M````$@`-`-,#``#(%P$``````!(`#0!=`P``+"D!`'`````2``T`?P$`````
M````````$@```#H#``!@(P$`)````!(`#0`#!```/``#```````0`!@`S0(`
M`!@``P`$````$0`8`/,#```T(`$`.````!(`#0`'`@`````````````2````
MZ`,``-A``0`\`0``$@`-`,4!`````````````!(```!6`0`````````````2
M````/P(`````````````$@```/,!`````````````!(````I`P``0"$!``0`
M```2``T`^P``````````````$@```$T"`````````````!(```#/`@``&``#
M``0````A`!@`7`0``!0``P`$````$0`7`-H#```8``,``````!``&`!&````
M```````````2````Y```````````````$@```,\#``````,``````"``%P!V
M````W!,!```````2````^@$`````````````$@```"D"`````````````!(`
M``#5`0`````````````2````S`$`````````````$@```$(!````````````
M`!(```"N`0`````````````2````D@$`````````````$@```,T#``````,`
M`````!``%P!\`@`````````````2````E@``````````````$@````4!````
M`````````!(```#7`@`````````````2````(`(`````````````$@```&("
M``"P%0$`&`(``!(`#0`V!```&``#```````0`!<`3P0``$0A`0`<`@``$@`-
M`-,``````````````!(```"W```````````````2````=`$`````````````
M$@```$<#``"8,`$`@`(``!(`#0"=`0`````````````2````:P,``&P@`0#4
M````$@`-`.0!`````````````!(````D!```/``#```````0`!@`AP``````
M````````$@````P"`````````````!(```"#`@`````````````2````)`$`
M````````````$@```'4"`````````````!(````$!```/``#```````0`!@`
M&0(`````````````$@```!,"`````````````!(```"!`P``A",!`#`!```2
M``T`#P0``!@``P``````$``8``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!0
M97)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X
M=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N
M9'5M<`!097)L7VYE=UA37V9L86=S`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3
M`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R
M;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]S=&%C:U]C:&M?9F%I;`!E
M>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`
M<W1R<F-H<@!U;FQI;FL`;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E
M860`<W1R<W1R`&UK9&ER`&=E='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R
M:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M
M86EN`'-T9&5R<@!M96UC:'(`<W1R8VAR`&UE;6-M<`!M96US970`;W!E;F1I
M<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A=&EO
M;@!A8F]R=`!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?
M7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S8`;&EB8RYS;RXV`&QD
M+6QI;G5X+6%R;6AF+G-O+C,`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA
M;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E
M9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS7VEN
M:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?
M96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,
M24)#7S(N,S0`1TQ)0D-?,BXS,P`````!``$``0`!``$``0`!``$``@`"``(`
M`@`"``$``@`"``$``0`!``(``0`!``(``@`"``(``0`"``4``0`"``(``0`#
M``(`!``"``$``0`"``(``0`!``$``0`!``$``@`!``(``0`"``$``@`"``$`
M`0`#``(``0`!``$``0`!``$``@`"``(``@`!``(``0`!``(``0`!``(``@`!
M``$``0`!``$``0`!``(``0`"``$``0`"``(``0`"``$``@`"``$``0`!``$`
M%0,``!`````@````%&EI#0``!`!S!`````````$``P`+`P``$`````````"T
MD98&```%`'T$```0````LY&6!@```P"(!```$````!1I:0T```(`<P0`````
M``#T_P(`%0$``/C_`@`3!```Y/T"`!0D```8``,`%#```"```P`4#P``*``#
M`!0&``#\_@(`%F$```#_`@`6.0``!/\"`!8-```(_P(`%A<```S_`@`62@``
M$/\"`!9+```4_P(`%E0``!C_`@`6!P``'/\"`!8!```@_P(`%EX``"3_`@`6
M1@``*/\"`!8%```L_P(`%EP``##_`@`670``-/\"`!89```X_P(`%D@``#S_
M`@`6&```0/\"`!8E``!$_P(`%C(``$C_`@`6'```3/\"`!8B``!0_P(`%CX`
M`%3_`@`6'@``6/\"`!9!``!<_P(`%E(``&#_`@`66@``9/\"`!9"``!H_P(`
M%E@``&S_`@`6(P``</\"`!8*``!T_P(`%E,``'C_`@`61```?/\"`!9;``"`
M_P(`%C4``(3_`@`610``B/\"`!8_``",_P(`%C0``)#_`@`63```E/\"`!8+
M``"8_P(`%A0``)S_`@`65@``H/\"`!8V``"D_P(`%C<``*C_`@`6'P``K/\"
M`!8Z``"P_P(`%BD``+3_`@`630``N/\"`!85``"\_P(`%F```,#_`@`6+0``
MQ/\"`!9.``#(_P(`%@D``,S_`@`6#```T/\"`!80``#4_P(`%A8``-C_`@`6
M0P``W/\"`!82``#@_P(`%AT``.3_`@`6(```Z/\"`!8H``#L_P(`%D<``/#_
M`@`6&@``"$`MZ58!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y2SL`0``QH_B'LJ,
MXBS\O.4`QH_B'LJ,XB3\O.4`QH_B'LJ,XAS\O.4`QH_B'LJ,XA3\O.4`QH_B
M'LJ,X@S\O.4`QH_B'LJ,X@3\O.4`QH_B'LJ,XOS[O.4`QH_B'LJ,XO3[O.4`
MQH_B'LJ,XNS[O.4`QH_B'LJ,XN3[O.4`QH_B'LJ,XMS[O.4`QH_B'LJ,XM3[
MO.4`QH_B'LJ,XLS[O.4`QH_B'LJ,XL3[O.4`QH_B'LJ,XKS[O.4`QH_B'LJ,
MXK3[O.4`QH_B'LJ,XJS[O.4`QH_B'LJ,XJ3[O.4`QH_B'LJ,XIS[O.4`QH_B
M'LJ,XI3[O.4`QH_B'LJ,XHS[O.4`QH_B'LJ,XH3[O.4`QH_B'LJ,XGS[O.4`
MQH_B'LJ,XG3[O.4`QH_B'LJ,XFS[O.4`QH_B'LJ,XF3[O.4`QH_B'LJ,XES[
MO.4`QH_B'LJ,XE3[O.4`QH_B'LJ,XDS[O.4`QH_B'LJ,XD3[O.4`QH_B'LJ,
MXCS[O.4`QH_B'LJ,XC3[O.4`QH_B'LJ,XBS[O.4`QH_B'LJ,XB3[O.4`QH_B
M'LJ,XAS[O.4`QH_B'LJ,XA3[O.4`QH_B'LJ,X@S[O.4`QH_B'LJ,X@3[O.4`
MQH_B'LJ,XOSZO.4`QH_B'LJ,XO3ZO.4`QH_B'LJ,XNSZO.4`QH_B'LJ,XN3Z
MO.4`QH_B'LJ,XMSZO.4`QH_B'LJ,XM3ZO.4`QH_B'LJ,XLSZO.4`QH_B'LJ,
MXL3ZO.4`QH_B'LJ,XKSZO.4`QH_B'LJ,XK3ZO.4`QH_B'LJ,XJSZO.4`QH_B
M'LJ,XJ3ZO.4`QH_B'LJ,XISZO.4`QH_B'LJ,XI3ZO.4`QH_B'LJ,XHSZO.4`
MQH_B'LJ,XH3ZO.4`QH_B'LJ,XGSZO.4`QH_B'LJ,XG3ZO.4`QH_B'LJ,XFSZ
MO.4`QH_B'LJ,XF3ZO.4`QH_B'LJ,XESZO.4`QH_B'LJ,XE3ZO.4`QH_B'LJ,
MXDSZO.4`QH_B'LJ,XD3ZO.4P0"WI)-!-XM0QG^44`(WE$!"-Y0P@C>44`(WB
M$!"-X@P@C>(`,)/E'#"-Y0`PH./@___KK"&?Y:P!G^4"$*#A7`L`ZZ0QG^4`
M0-/E``!4XT$```J8,9_E5`L`ZQ10G>4#,)_G`R"0YP0`A>('`7#CQC/2Y0-0
MA>(#,(/CQC/"Y5$``(H``:#AM?__ZV1!G^40$)WE8"&?Y0S`DN44()WE`0!2
MXP`PH.$$`(3E``"1Y0C`@^4``(/E0`&?Y00`@^4\`9_E#`"#Y4```-H$`$'B
M`@&`X`S`@^($X+'E`0!0X03@K.7[__\:`Q""X@``H.,``(WE!2"@X0$!@^<$
M$9_E#`"4Y17__^L`4%#B'@``"@P`E.5B___K[`"?Y1@0C>)Z``#K``!0XQL`
M``H,`)3E^_[_ZS;__^ND,)_E`""3Y1PPG>4"(#/@`#"@XR,``!H%`*#A)-"-
MXC"`O>@:___KD""?Y0``4.,,`(+E&0``"C/__^N4,)_E#`L`ZP,PG^<#,)#G
M>T?#Y;'__^H,`)3E_O[_ZP!0H.'<___J"`"4Y0``4.,!```*[@8`Z][__^I<
M`)_E&!"-XE0``.L``%#C"`"$Y=C__PKV___J.O__ZP00H./$___J`0"@XX'_
M_^M$___KY/T"`!P3`0#<$P$`*``#`.#I`0`L``,`"``#`!!'`0`41P$`N!\!
M`-Q$`0#$Z`$`>$0!``"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1R@G^48,(_B
M`Z"*X``PH.,$,"WE#`"?Y0``FN=<___KMO[_Z^SF`0`,`0``%#"?Y10@G^4#
M,(_@`B"3YP``4N,>_R\!O_[_ZM3F`0`$`0``&`"?Y1@PG^4``%/A'O\O`1`P
MG^4``%/C'O\O`1/_+^$8``,`&``#```````D`)_E)#"?Y0`P0^"C'Z#A0Q&!
MX,$0L.$>_R\!$#"?Y0``4^,>_R\!$_\OX1@``P`8``,``````!!`+>D80)_E
M`##4Y0``4^,0@+T8X/__ZP$PH.,`,,3E$("]Z"D``P#F___J\$<MZ0"`4.(J
M```*M#"?Y0"0D^4``%GC*```"@!0V.4!<*#A``!5XST`51,!4*`3`%"@`Q$`
M`!H`0)GE``!4XPP```H)8*#A!`"@X04@H.$($*#A"O__ZP``4.,"```:!3#4
MYST`4^,+```*!$"VY0``5./S__\:!`"@X?"'O>@(4*#A`3#UY0``4^,]`%,3
M^___&@A01>#F___J"6!&X`%0A>)&8:#A!4"$X`0`H.$`8(?E\(>]Z`A`H.'M
M___J"4"@X>O__^H8``,`$$`MZ7#03>)P,)_E#1"@X0!`H.$`,)/E;#"-Y0`P
MH./)_O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$P<```HT,)_E`""3
MY6PPG>4"(#/@`#"@XP<``!IPT(WB$("]Z`(0H.,$`*#A:_[_ZQ`/;^&@`J#A
M\?__ZJ;^_^OD_0(`1#&?Y?!`+>D`8%#B?-!-X@`PD^5T,(WE`#"@XP(```H`
M,-;E``!3XP<``!H8,9_E`""3Y70PG>4"(#/@`#"@XT```!I\T(WB\("]Z"+^
M_^L`0%#B]/__"@0`H.&N_O_K``!0XRD```H3,-#E$U"`XBX`4^,"```:`3#5
MY0``4^/T__\*$S#0Y2X`4^,D```*!@"@X57^_^L`<*#A!0"@X5+^_^L``(?@
M`@"`XG;^_^N8,)_E`"#@XP$0H.,$4(WE`&"-Y0!PH.&6_O_K"!"-X@<`H.$S
M_O_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!"5/C$@``"D#^_^L'`*#A(/[_ZP0`
MH.&$_O_K``!0X]7__QH$`*#A3?[_ZP8`H.%F_O_KP?__Z@$PU>4N`%/CU___
M&@(PU>4``%/CQO__"M/__^JN___KZ___ZE+^_^OD_0(`&$0!`/!/+>D!V$WB
M'-!-X@(0H.,`$(WE`>B-XB`1G^4`(*#C`#"@XP`0D>44$([E`!"@XQ3@CN(`
MD*#A._[_ZP%@4.(`@,'BR"^@X<@_)N`",%/@<S#_Y@(P(^`",%/@`B#"X`-@
M5N`"@,C@``!8XR\``+K,H)_ES'"?Y<RPG^4,4(WB`!"@XP@PH.$&(*#A"0"@
MX0`0C>4D_O_K"B"@X040H.$)`*#AY/W_ZP<`4.,:``":"`!`X@!`E>`#```Z
M%@``Z@%`1.(%`%3A$P``.@@@H.,'$*#A!`"@X:W]_^L``%#C]O__&@5`1.`&
M`)3@Q!^HX`'(C>)$,)_E%,",X@`@D^4`,)SE`B`SX``PH.,*```:`=B-XAS0
MC>+PC[WH`6A6X@"`R.(!`'CC"P!6`=/__QH``.#C`!"@X>S__^H`_O_KY/T"
M``@``0`(``,```#__W!`+>D!VDWB"-!-XMPPG^4`8*#A`0J-X@0`@.(`,)/E
M`#"`Y0`PH./$()_EQ`"?Y0%0H.$$$(WB"_[_ZP!`4.('``#:`2!$X@@PC>("
M,(/@!#!3Y0``4^,4```:``!2XQ$``!J0,)_ECPD`ZP4@H.$#,)_G!A"@X0,`
MD.>+_?_K`1J-XF0PG^4$$('B`""3Y0`PD>4"(#/@`#"@XQ(``!H!VHWB"-"-
MXG"`O>@"0*#A!""@X2\0H.,$`(WB`O[_ZP``4./F__\*,!"?Y78)`.L$,*#A
M`1"?YP0@C>(!`)#G!A"@X:3]_^OD___JP/W_Z^3]`@#_#P``($0!`,SB`0!H
MX@$`\$<MZ0%`H.$`,-'EX"&?Y0C03>(]`%/C`4"!`@!0H.$$`*#A`""2Y00@
MC>4`(*#CA/W_ZPT0H.$`8*#A!0"@X;#^_^L`D%#B/```"GW]_^L``%;A,P``
MF@!PG>64@9_E!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4PH.$!(//E
M``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"8Y8_]_^L``%#C!P"&YQ4```H`
M()CE!0"@X0$PT.0'$)+G``!3XST`4Q,`,,'E!@``"@$@@>(!,-#D`A"@X3T`
M4^,``%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!,-3D``!3XP$PXN7[__\:Y#"?
MY0`@D^4$,)WE`B`SX``PH.,S```:"-"-XO"'O>@!D$GB`3#4Y```4^,!,.GE
M^___&O'__^JP@)_E`'"8Y0`PE^4``%/C(P``"@<PH.$$(+/E"1"@X0``4N,!
MD(GB^O__&@,0@>(!$:#A@#"?Y0`@D^4``%+C#P``&@$@H.,!`*#A`""#Y5/]
M_^L`H%#BVO__"@<0H.$)<:#A!R"@X5_]_^L`H(CE`)"-Y0&0B>(`,*#C"3&*
MYZ?__^H'`*#A=?W_ZP``4.,`H*#A``"(Y<K__PH)<:#A\O__Z@.0H.$($*#C
MX/__ZC[]_^OD_0(`&``#`"P``P`P0"WIYP@`ZTQ0G^4,T$WB`$"@X050G^=`
M,)_E0""?Y4`0G^4%`)#G6OW_ZS@0G^4X,)_E`,"@XP$0G^<P()_E`0"4YRP0
MG^4$P(WE`#"-Y?;\_^L,T(WB,("]Z"3@`0!DA0$`T!,!`#!$`0``X`$`#$<!
M`)@P`0!,1`$`$$`MZ<@(`.L80)_E&#"?Y1@@G^4$0)_G%!"?Y00`D.<00+WH
M//W_ZJC?`0!DA0$`T!,!`#!$`0`P0"WI`MI-XAS03>*P,)_E`AJ-XA00@>(`
M,)/E`#"!Y0`PH.,<_?_KF!"?Y9@PG^68()_E\`#-X0$0H.,,`(WB(?W_ZP$:
MC>(!*J#C$!"!X@P`C>(6_?_K`$!0XA8``+H!`(3B\?S_ZP!04.(2```*`1J-
MX@0@H.$0$('BROS_ZP`PH.,$,,7G`AJ-XC`PG^44$('B`""3Y0`PD>4"(#/@
M`#"@XP,``!H%`*#A`MJ-XAS0C>(P@+WHW_S_ZP!0H./P___JY/T"`'!$`0!D
M1`$``1```,G__^KP1RWI0MU-XO`QG^5!S8WB`%"@X0%@H.'D`9_E$!"-XCS`
MC.(`,)/E`#",Y0`PH./1_?_K+Q"@XP!`H.$%`*#A:OS_ZP``4.,-```*M`&?
MY040H.$&___K!0"@X4$=C>*8,9_E/!"!X@`@D^4`,)'E`B`SX``PH.-?```:
M0MV-XO"'O>@&`*#AJ?S_ZW@1G^6Y_/_K`)!0XNO__PH`,-GE:(&?Y6AQG^4`
M`%/C6&&?Y3H```H``%3C!```"@D0H.$$`*#AW_S_ZP``4.,K```*"0"@X7C\
M_^L!($#B`B")X`(`6>$`,*#A`*"@X0`PB3``$*`S`0"),@,``#H(``#J`P!0
MX0`0P^4"```*`2!SY2\`4N/Y__\*"0"@X6;\_^L`H*#A!0"@X6/\_^L*`(#@
M`0"`X@$*4./#__\J!S"@X0$JH.,!$*#C?`"-X@A0C>4$@(WE`)"-Y:7\_^L0
M$(WB?`"-XD+\_^L``%#C`P``&B`PG>4/.@/B`@E3XQ,```H&$*#A``"@XWO\
M_^L`D%#BK?__"@`PV>4``%/CQ/__&@``5.,"```*`##4Y2X`4^,"```*7)"?
MY0&@H./8___J`3#4Y0``4^/L__\*^/__Z@$0H.-\`(WB(OS_ZP``4./F__\:
M'`"?Y7P0C>*@_O_K?`"-XD[\_^N7___J6/S_Z^3]`@!X1`$`A$0!`)1$`0"@
M1`$`F$0!`'1$`0`00"WI+Q"@XP!`H.'_^__K``!0XP%`@!($`*#A$$"]Z#S\
M_^IP0"WI`=I-X@C03>(!&HWB$#&?Y0!04.($$('B`#"3Y0`P@>4`,*#C+@``
M"@`PU>4``%/C*P``"@_\_^L!((#B`0I2XP!`H.$S``"*!&"-X@40H.$&`*#A
M#?S_ZP$P1.(#,(;@`P!6X0D``"H$`(;@!2"-X@`0H.,"``#J`@!0X0`0P.4"
M```*`3!PY2\`4^/Y__\*+Q"@XP8`H.'2^__K``!0XP\```H&`%#A`#"@@P`P
MP(4&`*#A#?S_ZP$:C>)@,)_E!!"!X@`@D^4`,)'E`B`SX``PH.,1```:`=J-
MX@C0C>)P@+WH`1J-XC0PG^4$$('B`""3Y0`PD>4"(#/@`#"@XP8``!H<`)_E
M`=J-X@C0C>)P0+WH]?O_Z@``H./E___J_OO_Z^3]`@!T1`$`)#2?Y3!`+>D,
MT$WB'$2?Y1Q4G^4`,)/E!#"-Y0`PH.,-$*#A!`"@X??\_^L``%#C#```"@`0
MG>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___
M&NW__^K(0Y_EP%.?Y0T0H.$$`*#AX_S_ZP``4.,,```*`!"=Y0`@E>4!,8+@
M!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZGQ#G^5P
M4Y_E#1"@X00`H.'/_/_K``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E``!0XP$!
M@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J,$.?Y2!3G^4-$*#A!`"@
MX;O\_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B
M!""3Y0``4N,$((/D^___&NW__^KD0I_ET%*?Y0T0H.$$`*#AI_S_ZP``4.,,
M```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@
M@^3[__\:[?__ZIA"G^6`4I_E#1"@X00`H.&3_/_K``!0XPP```H`$)WE`""5
MY0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J
M3$*?Y3!2G^4-$*#A!`"@X7_\_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4`
M`%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^H`0I_EX%&?Y0T0
MH.$$`*#A:_S_ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___
M"@0P@^($()/E``!2XP0@@^3[__\:[?__ZK1!G^6049_E#1"@X00`H.%7_/_K
M``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4`
M`%+C!""#Y/O__QKM___J:$&?Y4!1G^4-$*#A!`"@X4/\_^L``%#C#```"@`0
MG>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___
M&NW__^H<09_E\%"?Y0T0H.$$`*#A+_S_ZP``4.,,```*`!"=Y0`@E>4!,8+@
M!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__Z@T0H.',
M`)_E'?S_ZP`04.(!```*L`"?Y5?]_^L-$*#AM`"?Y1;\_^L`$%#B`0``"J@`
MG^50_?_K#1"@X:``G^4/_/_K`!!0X@P```IP`)_E2?W_ZT@PG^4`()/E!#"=
MY0(@,^``,*#C#```&G00G^5$`)_E#-"-XC!`O>@^_?_J#1"@X6``G^7]^__K
M`!!0XN___PHL`)_E-_W_Z^S__^KQ^O_KY/T"`*1$`0`8``,`L$0!`+A$`0#$
M1`$`S$0!`-Q$`0!X1`$`Z$0!`/1$`0``10$`A$0!``Q%`0`@10$`-$4!`$!%
M`0!D10$`4$4!``3@+>4,T$WB6#"?Y5@`G^4-$*#A`#"3Y00PC>4`,*#CV_O_
MZP``4.,%```*``#0Y0``4.,P`%`3`0"@`P``H!,!`"#B'#"?Y0`@D^4$,)WE
M`B`SX``PH.,!```:#-"-X@3PG>3$^O_KY/T"`.A$`0`00"WI>/K_ZY[Z_^L`
M`%#C``"0%1"`O>AP0"WI&-!-XNPPG^4`4*#A$!"-XN0`G^4`,)/E%#"-Y0`P
MH..X^__K`$!0X@X```H`,-3E``!3XPL```H%$*#AD_K_ZP``4.,2```*J#"?
MY0`@D^44,)WE`B`SX``PH.,D```:&-"-XG"`O>B(,)_E`""3Y10PG>4"(#/@
M`#"@XP40H`%T`)\%&@``&AC0C>)P0+WHVOS_Z@4`H.%J^O_K`&"@X00`H.%G
M^O_K``"&X`(`@.*+^O_K1#"?Y0`@X.,!$*#C&`"-Z0!0C>4T,)_E`$"@X:KZ
M_^L<,)_E`""3Y10PG>4"(#/@`#"@XP00H`$(`)\%Y/__"GWZ_^OD_0(`:$4!
M`)1$`0"81`$`=#6?Y?!/+>D`8*#A!P"3Z.S03>(DP(/B#$"#XH!0C>)8-9_E
M!P"%Z``PD^7D,(WE`#"@XP\`M.B8X(WBC'"-X@\`KN@#`)3H`P".Z`<`G.@'
M`(?H&!"-XB0%G^5G^__K`$!0X@(```H`,-3E``!3X_H``!H3^O_K.?K_ZP``
M4.-O```*`)"0Y0``6>-L```*"0"@X2GZ_^N``*#A`0"`XDWZ_^L`,-GE``!3
MXP!`H.$`<*#A"@``"LB$G^4$`*#A`#"-Y0`@X.,(,*#A`1"@XVCZ_^L!,/GE
M`D"$X@``4^/U__\:H`2?Y9B`C>("``#J!`"XY0``4.,-```*&!"-XC[[_^L`
M0%#B^/__"@`PU.4``%/C]?__"FO[_^L``%#C\O__"@0`H.$B^O_K`$!0X@P`
M`!H$0)7D``!4XPD```H`,-3E``!3X[4```H$`*#A7?O_ZP``4./Q__\:!$"5
MY```5./U__\:!`"@X?/Y_^L8E)_E`*"@X0<`H.'O^?_K`*"*X`&KBN($H(KB
M"@"@X1'Z_^OX,Y_E`"#@XP$0H.,(,(WE#'"-Y>@SG^4`0(WE!)"-Y0"`H.$N
M^O_K!QV@XP@`H.&/^?_K`0!PXP,``!I#^O_K`!"0Y1$`4>.6```:&!"-X@@`
MH.$*^O_K`%!0XB<```J@$Y_E`#"6Y9PCG^4``)'E`1"@XP"`C>7X^?_K`'"@
MXV0SG^4`()/EY#"=Y0(@,^``,*#CT@``&@<`H.'LT(WB\(^]Z-[Y_^L`D%#B
M>0``&@0`E^0``%#C"0``"A@0C>+I^O_K`#!0XOC__PH`,-/E``!3X_+__QH$
M`)?D``!0X_7__QH-`*#CUOG_ZQR3G^53,*#C`$"@X0!PH.&(___J*#"=Y0\Z
M`^(!"5/CT___&C!`G>6&^?_K``!4X<___QHH,)WE@SN@X:,[H.$'#5/CRO__
M&@H`H.'"^?_K&!"-X@!PH.'(`I_EQ_K_ZP`04.)H```*``"6Y>3\_^L`H%#B
M9```"@H`H.&/^?_K`P!0XP!`H.$+``":!`!`XI02G^4``(K@Z_G_ZP``4.,%
M```:!`!4XX0```H$0(K@!3!4Y2\`4^.````*;`*?Y1@0C>*M^O_K``!0XP,`
M``H`,-#E,`!3XP``4Q,$```:"@"@X0`0H..#^?_K`$!0XD<``!HX$I_E,`*?
MY=W[_^NP^?_K+&*?Y2PRG^4`(.#C`1"@X_"`S>$,8(WE'**?Y0@`C>4'`*#A
MLOG_ZPX``.K+^?_K`#"0Y1$`4^,0```:H/G_ZP%0A>(*,*#A!""@X0$0H.,0
M8(WE#%"-Y0#`H.$'`*#A`!.-Z*+Y_^L'':#C!P"@X0/Y_^L!`'#C`$"@X>K_
M_PH(`*#A,?G_ZW`!G^4'$*#AM_O_ZP<`H.&T_O_K>___Z@-`H.%.___J0_G_
MZX``H.$!`(#B&/__ZE@!G^4`,);E>"&?Y0``D.4$$(WE`("-Y0$0H.-E^?_K
M:___ZJ/^_^L4,9_E`""3Y>0PG>4"(#/@`#"@XSX``!H$`*#A[-"-XO!/O>A*
M^?_J`*"6Y9C__^H"^__K`*!1X@!@H.&S__^Z"B!0X@"PH.,`,,KB!`"@X0"P
MC>5$^?_K!B"@X[`0C>($`*#A!/G_Z_0PG^6P()WE`P!2X:7__QJT*]WAY#"?
MY0,`4N&A__\:,B!6X@`PRN*X4(WB!`"@X0"PC>4R^?_K!1"@X00`H.$H(*#C
M\OC_ZYP@G^6P,)_E#""-Y0$0H.,`(.#C!P"@X0A0C>7P@,WAX+#-Y4[Y_^NP
M___J!$"6Y0``5.-[__\*!`"@X?KX_^L#`%#C=___F@0`0.)L$)_E``"$X%?Y
M_^L``%#C!*"@`7#__^H:^?_K<(4!`.3]`@!X1`$`@$4!`#1%`0"@1`$`E$4!
M`(A%`0`@``,`V$4!`'A%`0`L1@$`-$8!`.A$`0!D10$`#$<!`%1&`0!D1@$`
MG$4!``!#04-(10``1$8!`#Q&`0`H(I_E<$`MZ0C03>(@,I_E`""2Y00@C>4`
M(*#CJ00`ZP,PG^<-$*#A`T"0YP0"G^5H,-3E:3#$Y?KY_^L``%#C`@``"@`P
MT.4Q`%/C80``"O'\_^O@,9_EF@0`ZP,PG^<#0)#G!`"@X=`1G^4#,*#C`2"@
MXX[X_^L`0%#B#0``"KPQG^40()3EC@0`ZP,PG^<`$)+E`%"@X:@AG^4#`)#G
MB?C_ZQ`PE.4`$)/E"#"1Y0$%$^-2```:C"&?Y8$$`.N($9_E`B"?YP!0H.$#
M,*#C`@"0YP$@H.-U^/_K`$!0X@H```IH`9_E#1"@X<WY_^L`(%#B.P``"E@Q
MG^40$)3E`S"?YP`0D>4#`)7G;OC_ZT11G^5$,9_E:@0`ZT`1G^4#,)_G`$"@
MX0$@H.,#8)#G!@"@X4SX_^LH(9_E`!"@X08`H.%@^/_K'#&?Y0`@H.,8`9_E
M`S"?YPT0H.$#,)3G:2##Y:_Y_^L``%#C`$"@X0@`A>4/```*!QV@XP0`H.$J
M^/_K`2"`XA$`4.,!`%(3`#"@X2```(J0,)_E`""3Y00PG>4"(#/@`#"@XQD`
M`!H(T(WB<("]Z`0`E>49_O_K``!0XP!`H.$(`(7EZ?__&IP`G^6B^/_K`3#0
MY0``4^.?__\*F?__ZFQ0G^40()3E!#"5Y0``DN4`$)/EAOK_Z\/__^IL,)_E
M`S"?YP,`E>=U^/_KI___ZGSX_^L$()7E5`"?Y0`0DN4$(*#AC/C_Z^3]`@`X
MSP$`S$0!`/S.`0!X1@$`S,X!`'Q&`0"4S@$`A$8!`(1$`0!8S@$`+``#`#C.
M`0"(1@$`H$8!``3.`0!X1`$`J$8!`%#-`0#,1@$`Z#"?Y3!`+>D,T$WB`#"3
MY00PC>4`,*#C`%"@X1+\_^LO$*#C`$"@X0KX_^L``%#C`4"`$@0`H.%(^/_K
M#1"@X0!`H.&H`)_E5OG_ZP`P4.(*```*`##3Y3``4^,``%,3`3"@`P`PH!,!
M,"/B``!5XP`PH`,!,`,2``!3XP<``!IH,)_E`""3Y00PG>4"(#/@`#"@XQ0`
M`!H,T(WB,("]Z``PU>4``%/C]/__"D00G^4$(*#C!`"@X5OX_^L``%#C[O__
M&B0PG^4`()/E!#"=Y0(@,^``,*#C`P``&@4`H.$,T(WB,$"]Z(+Y_^HG^/_K
MY/T"`.A$`0"410$``````"@\G^7P3RWI`!"@X:7?3>)``(#B@&"!X@@@C>(`
M,)/EC#*-Y0`PH.,`4*#C!,`0Y0C@$.4(`(#B+#2@X?\\`^(L/(/A#$2@X0P\
M@^'_2`3B/L^_Y@0P@^$&`%#A`,""Y010@N4(,(+E#%""Y1`@@N+M__\:(3Z-
MX@`PC>6`,)WE!!"-Y7"`G>5T()WE$+"=Y7APG>5\8)WEA,"=Y0A0G>4,0)WE
M%*"=Y1``C>(#$*#A`0``Z@FPH.$#H*#A`3"@X3S@D.4X$)#E")"PY0D0(>`(
M$"'@!X"@X0-PH.$`,*#C=#"`Y00PD.4%$"'@`^`NX`+@+N`$X"[@!B"@X0Q@
MH.&ASZ#ACL",X0$0D>`,$('A`,"=Y0M0H.$``%SA"D"@X0#`H.-P$(#EX?__
M&@00G>7\.I_E"""=Y0"0D>4!")'I(,"1Y0,@DN`,()+@J<V@X1"`D>48H)'E
M@,*,X0Q`D>6)PHSA`L"<X`H@*.`KX:#A"R`"X`H@(N`$[X[A`L"<X`OOCN$0
M()WE*4&@X0!/A.$.`"C@`R"2X`D``.`(`"#@"B"2X`E/A.$`()+@&`"=Y010
M+N`#`)#@#%`%X.PM@N`.4"7@"`"0X`4`D.#B78#@(`"=Y;!@G>4#`)#@#@"0
MX&SA).`"X`[@!.`NX`[@D.`H`)WE8B&@X0,`D.`$`)#@;$$BX`5`!.#E[8[@
M;$$DX`0`D.#N38#@,`"=Y0,`D.!L`8#@9<$BX`[`#.`"P"S@#`"0X#C`G>5N
MX:#A`\"<X`(@G.!EP2[@!,`,X.0-@.!EP2S@#""2X.#-@N!`()WE`R"2X&4A
M@N!D42[@`%`%X`Y0)>`%()+@2%"=Y6`!H.$#4)7@#N"5X&11(.`,4`7@["V"
MX&11)>`%X)[@XEV.X%#@G>4#X)[@9.&.X&Q!(.`"0`3@`$`DX`3@GN!80)WE
M8B&@X0-`E.```)3@;$$BX`5`!.#E[8[@;$$DX`0`D.#N38#@8`"=Y0,`D.!L
M`8#@9<$BX`[`#.`"P"S@#`"0X&C`G>5NX:#A`\"<X`(@G.!EP2[@!,`,X.0-
M@.!EP2S@#""2X.#-@N!P()WE`R"2X&4A@N!D42[@`%`%X`Y0)>`%()+@>%"=
MY6`!H.$#4)7@#N"5X&11(.`,4`7@["V"X&11)>`%X)[@XEV.X(#@G>4#X)[@
M9.&.X&Q!(.`"0`3@`$`DX`1`GN"(X)WE8B&@X0/@GN```)[@;.$BX`7@#N#E
M383@;.$NX`X`D.#D[8#@D`"=Y0,`D.!L`8#@9<$BX`3`#.`"P"S@#`"0X)C`
MG>5D0:#A`\"<X`(@G.!EP23@#L`,X.X-@.!EP2S@#""2X.#-@N"@()WE`S"2
MX&XA).``(`+@!"`BX&4Q@^`",)/@["V#X*A0G>48.)_E8`&@X0-0E>`$4)7@
M;D$@X`Q`).`$0)7@`U"6X&Y1A>"X8)WE;.$@X`+@+N#B383@#N"5X&(AH.$#
M4);@`%"5X,!@G>5L`2+@Y.V.X`0`(.```)7@`V"6X.Y=@.!LP8;@9`$BX,A@
MG>4.`"#@``"<X&[AH.$#P);@`L"<X-!@G>5D(2[@!2`BX.4-@.`"()S@`\"6
MX&3!C.#88)WE94$NX.`M@N``0"3@!$"<X&`!H.$#P);@#L"<X.!@G>7B[83@
M94$@X`)`).`$0)S@`\"6X&7!C.#H8)WE8E$@X`Y0)>`%4)S@;L&@X0-@EN#N
M383@``"6X&+A+.#P8)WE!.`NX`[@D.`#8);@Y%V%X&0!+.!B(8;@^&"=Y04`
M(.#E[8[@`""2X&4!H.$#8);@#&"6X&3!(.#N+8+@`'&=Y0[`+.`,P);@XFV,
MX`-PE^`(49WE;L$@X&1!A^`"P"S@#,"4X&(AH.$#0)7@`$"4X!!1G>5N`2+@
MYLV,X`8`(.```)3@`U"5X.Q-@.!NX87@9@$BX!A1G>4,`"#@``">X&S!H.$#
MX)7@`N">X"!1G>5F(2S@!"`BX`(@GN`#X)7@Y`V`X&;ACN!D42S@*&&=Y0!0
M)>#@+8+@!5">X&`!H.$#8);@#,"6X&3A(.`P89WE`N`NX.)=A>`.X)S@`\"6
MX&3!C.`X89WE8D$@X.7MCN`%0"3@!$"<X&51H.$#P);@`,"<X$!AG>7N#83@
M8D$EX`Y`).`$0)S@`S"6X&(Q@^!N(27@`"`BX`(@D^!(P9WES#6?Y>!-A.`#
MP)S@8`&@X07`G.!N48#A;F$`X%!QG>4$4`7@!E"%X07`G.`#4)?@Y"V"X&Y1
MA>!DX8#A9&$`X%AQG>4"X`[@XLV,X`;@CN%B(:#A!5">X`/@E^``X)[@[`V%
MX&11@N%D80+@#%`%X&!QG>4&4(7A#E"5X&SA@N$#<)?@;&$"X`#@#N#@787@
M9$&'X`;@CN$$X)[@Y6V.X&CAG>5@`:#A`^">X`(@GN!LX8#A;$$`X'!QG>4%
MX`[@!.".X0+@GN`#<)?@92&`X>9-CN!LP8?@9>$`X'AQG>4&(`+@#B""X69A
MH.$,P)+@`R"7X``@DN#D#8S@9<&&X67A!N"`<9WE!,`,X`[`C.$"X)S@`\"7
MX&0AAN%EP8S@`"`"X&11!N#@[8[@!2""X0P@DN#NS8+@B"&=Y6`!H.%D48#A
M`R"2X`8@DN"0<9WE9&$`X`Y0!>`&4(7A`E"5X`-PE^!N(8#A;F$`X&1!A^`,
M(`+@F'&=Y>Q=A>`&((+A;,&@X01`DN`#()?@`""2X.4-A.!N08SA;F$,X`5`
M!."@<9WE!D"$X0)`E.!E(8SAX&V$X`-PE^!E00S@`"`"X&[AA^`$((+A#B"2
MX.;M@N"H(9WE8`&@X0,@DN`,()+@9<&`X65!`."P<9WE!L`,X`3`C.$"0)S@
M`\"7X&8A@.&X<9WE9<&,X`X@`N!F40#@[DV$X`4@@N%NX:#A#,"2X`,@E^``
M()+@Y`V,X&;!CN%F40[@P'&=Y03`#.`%P(SA`E"<X`/`E^!D(8[A9L&,X``@
M`N!D80[@X%V%X`8@@N$,()+@Y<V"X,@AG>5@`:#A`R"2X`!@H.,.()+@9.&`
MX=!QG>4%X`[@!&"!Y0Q@@>448('E'&"!Y61A`.`&X([A`N">X`-PE^!E(8#A
M96$`X&1!A^`,(`+@V'&=Y08@@N'L[8[@!$"2X&S!H.$#()?@`""2X&4!C.%E
M80S@#@``X.!QG>4&`(#A[DV$X`(`D.!N(8SA`W"7X&YA#.`$(`+@T#*?Y>0-
M@.!E48?@!B""X>AQG>5D0:#A!2"2X.!=@N#P89WE;B$DX`-PE^`,P)?@`"`B
MX`(@G.`#P);@;L&,X/AAG>7E[8+@8"$DX`4@(N`"()S@95&@X0-@EN`$0);@
M8,$EX`!BG>4.P"S@#,"4X`-`EN#N+8+@8$&$X`ABG>5N`27@`@`@X.+-C.``
M`)3@8B&@X0-@EN`%4);@;D$BX!!BG>4,0"3@!$"5X`-0EN#L#8#@&&*=Y6Y1
MA>!LX2+@`.`NX.!-A.`.X)7@8`&@X0-0EN`"4)7@(&*=Y6PA(.#D[8[@!"`B
MX`(@E>`#8);@[EV"X&S!AN!D(2#@*&*=Y0X@(N`"()S@;N&@X0/`EN``P)S@
M,&*=Y60!+N#E+8+@!0`@X```G.`#P);@9,&,X#ABG>7B38#@90$NX`(`(.``
M`)S@8B&@X0-@EN`.X);@9<$BX$!BG>7D#8#@!,`LX`S`GN`#X);@9>&.X$AB
MG>7@78S@9,$BX`#`+.`,P)[@8`&@X0/@EN`"X)[@4&*=Y60A(.#ES8S@!2`B
MX`(@GN`#X);@9.&.X%ABG>7L38+@92$@X`P@(N`"()[@;,&@X0/@EN``X)[@
M8&*=Y64!+.#D+8+@!``@X```GN`#X);@9>&.X&ABG>7B78#@9`$LX`(`(.``
M`)[@8B&@X0/@EN`,X)[@<&*=Y63!(N`%P"S@#,">X`/@EN#E#8#@9.&.X&5A
M(N!X0IWE`&`FX.#-C.`&X)[@8`&@X0-`E.`"()3@96$@X(!"G>4,8";@[.V.
MX`8@DN`#,)3@;*&*X`DPD^!LP2#@[BV"X`[`+.!E,8/@##"3X.(]@^`@P)'E
M"R"2X&Z!B.``,('E&*"!Y1"`@>4((('E+#"?Y0P`D.``8*#C(`"!Y21@@>4`
M()/EC#*=Y0(@,^``,*#C`0``&J7?C>+PC[WH%_7_Z^3]`@"9>8):H>O9;MR\
M&X_6P6+*$$`MZ8``H.,,]?_K#GN?[0`@H.,`>X#M#7N?[7@@@.4">X#M#'N?
M[01[@.T,>Y_M!GN`[0Q[G^T(>X#M#'N?[0I[@.T,>X#M$("]Z`$C16<`````
MB:O-[P````#^W+J8`````'94,A``````\.'2PP```````````````/!'+>D"
MD*#A*#"0Y2P@D.6)P8/@`P!<X0`PH.,"(-/@`%"@X3`@D.4!0*#A-!"0Y<D/
MH.$!```J`2"2X@`0H>(L,(7EJ3Z@X8`Q@^$",)/@H!ZAX'@`E>4X@(7B``!0
MXRC`A>4P,(7E-!"%Y1\``!H_`%GC+@``VD"02>(I8Z#A`7"&X@=SA.`(,*#A
M0."$X@#`E.4$`)3E"!"4Y0P@E.400(3B#@!4X0#`@^4$`(/E"!"#Y0P@@^40
M,(/B\___&@4`H.&=_/_K!P!4X>W__QH&;6;@!I.)X`D@H.$'$*#A"`"@X97T
M_^MXD(7E\(>]Z$!P8.()`%?A"7"@H0``B.`'(*#A!!"@X8ST_^MX,)7E`S"'
MX$``4^-X,(7E\(>]&`4`H.$'D$G@!T"$X(/\_^O.___J!'"@X>;__^KP02WI
M.'"!XB@@D>4P8)'E,H^_YJ(QH.$_,`/B`2"#X@%`H.$X`%+C?Q#@XP!0H.$V
M;[_F`@"'X`,0Q^<\``#:0"!BX@`0H.,]]/_K!`"@X6O\_^L'`*#A.""@XP`0
MH.,W]/_K!`"@X7!@A.5T@(3E8_S_ZP,PU.4$`*#A`##%Y;(PU.$!,,7E`#"4
MY2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E
M"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;
M,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(R
MU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WH$O3_ZC@@8N(`$*#C`/3_
MZ\?__^H```````````\*X.,?\$#B"#"?Y0,PC^``,)/E7?3_ZI"\`0`(0"WI
M"("]Z`$``@`]````0`````L```!`````$````$`````F````0````#4```!`
M`````P```$`````&````0````!0```!`````#@```$`````-````0````"4`
M``!`````$@```$`````H````0`````(```!`````&````$`````)````0```
M``H```!````````````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!
M344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$52
M3#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!
M3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!,1%],24)2
M05)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P
M97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U-P```%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%35!$
M25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B
M+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*
M96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]
M("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@
M9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^
M>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O
M=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO
M9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I
M;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A
M<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@
M8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE
M>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D
M9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K
M97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@
M/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN
M72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L
M("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z
M("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I
M;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I
M;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*
M)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)
M3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L
M96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A
M9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*
M<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N
M86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O
M9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@
M;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I
M+F,````X1P$`=$0!```````T10$`.$4!`"Q'`0!\1`$`-$<!```````81P$`
M($<!````````0T%#2$4``#T```!`````"P```$`````0````0````"8```!`
M````-0```$`````#````0`````8```!`````%````$`````.````0`````T`
M``!`````)0```$`````2````0````"@```!``````@```$`````8````0```
M``D```!`````"@```$```````````````)"1_W\!````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"\&`$`E!@!```````!````^P(```$````+`P```0```!4#```,
M````J!(!``T```!\0P$`&0```-S]`@`;````!````!H```#@_0(`'`````0`
M``#U_O]OM`$!``4```#,"@$`!@```(P$`0`*````DP0```L````0````%0``
M```````#````\/X"``(```#P`0``%````!$````7````N!`!`!$```"($`$`
M$@```#`````3````"````!X````(````^___;P$```#^__]O*!`!`/___V\"
M````\/__;V`/`0``````````````````````````````````````````````
M``````````````````#H_0(```````````"T$@$`M!(!`+02`0"T$@$`M!(!
M`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`
MM!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T
M$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02
M`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!
M`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`M!(!`+02`0"T$@$`
MM!(!````````````L!4!````````````"E!!4BYP;0H`````0$<!`$=#0SH@
M*%)A<W!B:6%N(#$R+C(N,"TQ,"MR<&DQ*2`Q,BXR+C``02X```!A96%B:0`!
M)`````4V``8&"`$)`0H"$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````````
M``````````````````````````L````!`````@```%0!`0!4`0``&0``````
M`````````0`````````3````!P````(```!P`0$`<`$``"0`````````````
M``0`````````)@````<````"````E`$!`)0!```@```````````````$````
M`````#0```#V__]O`@```+0!`0"T`0``V`(```4`````````!`````0````^
M````"P````(```",!`$`C`0``$`&```&`````0````0````0````1@````,`
M```"````S`H!`,P*``"3!``````````````!`````````$X```#___]O`@``
M`&`/`0!@#P``R`````4``````````@````(```!;````_O__;P(````H$`$`
M*!```&`````&`````@````0`````````:@````D````"````B!`!`(@0```P
M````!0`````````$````"````',````)````0@```+@0`0"X$```\`$```4`
M```6````!`````@```!\`````0````8```"H$@$`J!(```P`````````````
M``0`````````=P````$````&````M!(!`+02``#\`@`````````````$````
M!````((````!````!@```+`5`0"P%0``S"T`````````````$`````````"(
M`````0````8```!\0P$`?$,```@```````````````0`````````C@````$`
M```"````A$,!`(1#``"T0@`````````````$`````````)8````!``!P@@``
M`#B&`0`XA@``"`````T`````````!`````````"A`````0````(```!`A@$`
M0(8```0```````````````0`````````JP````X````#````W/T"`-S]```$
M```````````````$````!````+<````/`````P```.#]`@#@_0``!```````
M````````!`````0```##`````0````,```#D_0(`Y/T```0`````````````
M``0`````````T`````8````#````Z/T"`.C]```(`0``!@`````````$````
M"````-D````!`````P```/#^`@#P_@``$`$`````````````!`````0```#>
M`````0````,```````,````!`!@```````````````0`````````Y`````@`
M```#````&``#`!@``0`D```````````````(`````````.D````!````,```
M```````8``$`)@```````````````0````$```#R`````P``<```````````
M/@`!`"\```````````````$``````````0````,``````````````&T``0`"
3`0`````````````!````````````
